@@ -207,7 +207,7 @@ def count_n_atoms(form_str:str):
 
     return n_atoms
 
-def index_elements(labels:list):
+def index_elements(labels:list,shift:int=0):
     """
     Return dictionary of element (keys) and indices (values) from list of labels
 
@@ -215,7 +215,7 @@ def index_elements(labels:list):
         labels (list) : atomic labels
 
     Keyword arguments:
-        None
+        shift (int)   : additive shift to apply to all indices
 
     Returns:
         ele_index (dict) : dictionary of element (keys) and indices (values)
@@ -227,9 +227,9 @@ def index_elements(labels:list):
 
     for it,lab in enumerate(labels_nn):
         try:
-            ele_index[lab].append(it)
+            ele_index[lab].append(it+shift)
         except KeyError:
-            ele_index[lab] = [it]
+            ele_index[lab] = [it+shift]
 
     return ele_index
 
